;; Generated package description from ampc.el  -*- no-byte-compile: t -*-
(define-package "ampc" "0.2.0.20221214.153219" "Asynchronous Music Player Controller" 'nil :commit "9fffb61cf060433fce9960d766eb3e641b6046ca" :url "https://elpa.gnu.org/packages/ampc.html" :authors '(("Christopher Schmidt" . "christopher@ch.ristopher.com")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("ampc" "mpc" "mpd"))
